@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: f; c-basic-offset: 4 -*- */
-/* $Id: ifplugd.c 110 2004-05-10 21:32:00Z lennart $ */
+/* $Id: ifplugd.c 116 2004-12-19 00:24:29Z lennart $ */
 
 /*
  * This file is part of ifplugd.
@@ -19,6 +19,10 @@
  * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -52,10 +56,6 @@
 #include "ifmonitor.h"
 #include "svn-revision.h"
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #define VARRUN "/var/run"
 #define IFPLUGD_ENV_PREVIOUS "IFPLUGD_PREVIOUS"
 #define IFPLUGD_ENV_CURRENT "IFPLUGD_CURRENT"
@@ -460,7 +460,10 @@ void work(void) {
         interface_status_t s;
         fd_set qfds = fds;
 		int d;
-        struct timeval tv = { polltime, 0 };
+        struct timeval tv;
+
+		tv.tv_sec = polltime;
+		tv.tv_usec = 0;
         
         if (select(FD_SETSIZE, &qfds, NULL, NULL, &tv) < 0) {
             if (errno == EINTR)
